@@ -3,20 +3,76 @@ package inventory
 import (
 	"fmt"
 	"net"
+	"strconv"
 	"strings"
 
-	"github.com/openshift/assisted-installer-agent/src/util"
 	"github.com/openshift/assisted-service/models"
 	"github.com/sirupsen/logrus"
 )
 
-const ipv6LocalLinkCIDR = "fe80::/10"
-
-type interfaces struct {
-	dependencies util.IDependencies
+//go:generate mockery -name Interface -inpkg
+type Interface interface {
+	MTU() int
+	Name() string
+	HardwareAddr() net.HardwareAddr
+	Flags() net.Flags
+	Addrs() ([]net.Addr, error)
+	IsPhysical() bool
+	SpeedMbps() int64
 }
 
-func newInterfaces(dependencies util.IDependencies) *interfaces {
+type NetworkInterface struct {
+	netInterface net.Interface
+	dependencies IDependencies
+}
+
+func (n *NetworkInterface) MTU() int {
+	return n.netInterface.MTU
+}
+
+func (n *NetworkInterface) Name() string {
+	return n.netInterface.Name
+}
+
+func (n *NetworkInterface) HardwareAddr() net.HardwareAddr {
+	return n.netInterface.HardwareAddr
+}
+
+func (n *NetworkInterface) Flags() net.Flags {
+	return n.netInterface.Flags
+}
+
+func (n *NetworkInterface) Addrs() ([]net.Addr, error) {
+	return n.netInterface.Addrs()
+}
+
+func (n *NetworkInterface) IsPhysical() bool {
+	evaledPath, err := n.dependencies.EvalSymlinks(fmt.Sprintf("/sys/class/net/%s", n.netInterface.Name))
+	if err != nil {
+		logrus.WithError(err).Warnf("Could not determin if interface %s is physical", n.netInterface.Name)
+		return true
+	}
+	return !strings.Contains(evaledPath, "/virtual/")
+}
+
+func (n *NetworkInterface) SpeedMbps() int64 {
+	b, err := n.dependencies.ReadFile(fmt.Sprintf("/sys/class/net/%s/speed", n.Name()))
+	if err != nil {
+		logrus.WithError(err).Warnf("Could not read %s speed", n.Name())
+		return 0
+	}
+	ret, err := strconv.ParseInt(strings.TrimSpace(string(b)), 10, 32)
+	if err != nil {
+		logrus.WithError(err).Warnf("Could not parse %s speed", n.Name())
+	}
+	return ret
+}
+
+type interfaces struct {
+	dependencies IDependencies
+}
+
+func newInterfaces(dependencies IDependencies) *interfaces {
 	return &interfaces{dependencies: dependencies}
 }
 
@@ -41,22 +97,10 @@ func (i *interfaces) getDeviceField(name, field string) string {
 
 }
 
-func ipWithCidrInCidr(ipWithCidrStr, cidrStr string) bool {
-	ip, _, err := net.ParseCIDR(ipWithCidrStr)
-	if ip == nil || err != nil {
-		return false
-	}
-	_, ipnet, err := net.ParseCIDR(cidrStr)
-	if err != nil {
-		return false
-	}
-	return ipnet.Contains(ip)
-}
-
 func analyzeAddress(addr net.Addr) (isIpv4 bool, addrStr string, err error) {
 	ipNet, ok := addr.(*net.IPNet)
 	if !ok {
-		return false, "", fmt.Errorf("could not cast to *net.IPNet")
+		return false, "", fmt.Errorf("Could not cast to *net.IPNet")
 	}
 	mask, _ := ipNet.Mask.Size()
 	addrStr = fmt.Sprintf("%s/%d", ipNet.IP.String(), mask)
@@ -89,7 +133,7 @@ func (i *interfaces) getInterfaces() []*models.Interface {
 		return ret
 	}
 	for _, in := range ins {
-		if !(in.IsPhysical() || in.IsBonding() || in.IsVlan()) {
+		if !in.IsPhysical() {
 			continue
 		}
 		rec := models.Interface{
@@ -118,28 +162,15 @@ func (i *interfaces) getInterfaces() []*models.Interface {
 			}
 			if isIPv4 {
 				rec.IPV4Addresses = append(rec.IPV4Addresses, addrStr)
-			} else if !ipWithCidrInCidr(addrStr, ipv6LocalLinkCIDR) {
+			} else {
 				rec.IPV6Addresses = append(rec.IPV6Addresses, addrStr)
 			}
 		}
 		ret = append(ret, &rec)
 	}
-	setV6PrefixesForAddresses(ret, i.dependencies)
 	return ret
 }
 
-func GetInterfaces(dependencies util.IDependencies) []*models.Interface {
-	return newInterfaces(dependencies).getInterfaces()
-}
-
-func setV6PrefixesForAddresses(interfaces []*models.Interface, dependencies util.IDependencies) {
-	for _, intf := range interfaces {
-		if len(intf.IPV6Addresses) == 0 {
-			continue
-		}
-
-		if err := util.SetV6PrefixesForAddress(intf.Name, dependencies, logrus.StandardLogger(), intf.IPV6Addresses); err != nil {
-			logrus.WithError(err).Warnf("Failed to set V6 prefix for interface %s address %s", intf.Name, intf.IPV6Addresses)
-		}
-	}
+func GetInterfaces(depenndecies IDependencies) []*models.Interface {
+	return newInterfaces(depenndecies).getInterfaces()
 }
