@@ -15,16 +15,15 @@ import (
 )
 
 const (
-	InfraEnvID                    = "11111111-1111-1111-1111-111111111111"
+	ClusterID                     = "11111111-1111-1111-1111-111111111111"
 	defaultnextInstructionSeconds = int64(1)
-	waitForWiremockTimeout        = 60 * time.Second
 )
 
 var log *logrus.Logger
 
 var _ = Describe("Agent tests", func() {
 	BeforeSuite(func() {
-		Eventually(waitForWiremock, waitForWiremockTimeout, time.Second).ShouldNot(HaveOccurred())
+		Eventually(waitForWiremock, 10*time.Second, time.Second).ShouldNot(HaveOccurred())
 		log = logrus.New()
 	})
 
@@ -39,9 +38,9 @@ var _ = Describe("Agent tests", func() {
 
 	It("Happy flow", func() {
 		hostID := nextHostID()
-		registerStubID, err := addRegisterStub(hostID, http.StatusCreated, InfraEnvID)
+		registerStubID, err := addRegisterStub(hostID, http.StatusCreated)
 		Expect(err).NotTo(HaveOccurred())
-		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds, "")
+		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds)
 		Expect(err).NotTo(HaveOccurred())
 		Expect(startAgent()).NotTo(HaveOccurred())
 		time.Sleep(1 * time.Second)
@@ -51,158 +50,55 @@ var _ = Describe("Agent tests", func() {
 		Expect(deleteStub(nextStepsStubID)).NotTo(HaveOccurred())
 	})
 
-	It("Next step runner fails - default delay", func() {
+	It("register forbidden", func() {
 		hostID := nextHostID()
-		registerStubID, err := addRegisterStubInvalidCommand(hostID, http.StatusCreated, InfraEnvID, -1)
+		registerStubID, err := addRegisterStub(hostID, http.StatusForbidden)
 		Expect(err).NotTo(HaveOccurred())
-		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds, "")
+
+		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds)
 		Expect(err).NotTo(HaveOccurred())
 
 		Expect(startAgent()).NotTo(HaveOccurred())
 		time.Sleep(10 * time.Second)
 
-		By("Validate only register request was called")
-		verifyNumberOfRegisterRequest("==", 1)
-		verifyNumberOfGetNextRequest(hostID, "==", 0)
-		Expect(deleteStub(registerStubID)).NotTo(HaveOccurred())
-		Expect(deleteStub(nextStepsStubID)).NotTo(HaveOccurred())
-	})
-
-	It("Next step runner keeps failing - retry registration", func() {
-		hostID := nextHostID()
-		registerStubID, err := addRegisterStubInvalidCommand(hostID, http.StatusCreated, InfraEnvID, 3)
-		Expect(err).NotTo(HaveOccurred())
-		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds, "")
-		Expect(err).NotTo(HaveOccurred())
-
-		Expect(startAgent()).NotTo(HaveOccurred())
-		time.Sleep(5 * time.Second)
-
-		By("Validate only register request was called, at least twice")
-		verifyNumberOfRegisterRequest(">", 1)
-		verifyNumberOfGetNextRequest(hostID, "==", 0)
-		Expect(deleteStub(registerStubID)).NotTo(HaveOccurred())
-		Expect(deleteStub(nextStepsStubID)).NotTo(HaveOccurred())
-	})
-
-	It("Next step runner fails once, retry succeeds", func() {
-		hostID := nextHostID()
-		registerStubID, err := addRegisterStubInvalidCommand(hostID, http.StatusCreated, InfraEnvID, 5)
-		Expect(err).NotTo(HaveOccurred())
-		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds, "")
-		Expect(err).NotTo(HaveOccurred())
-
-		Expect(startAgent()).NotTo(HaveOccurred())
-		time.Sleep(3 * time.Second)
-
-		By("Validate only register was called")
-		verifyNumberOfRegisterRequest("==", 1)
-		verifyNumberOfGetNextRequest(hostID, "==", 0)
-		Expect(deleteStub(registerStubID)).NotTo(HaveOccurred())
-
-		registerStubID, err = addRegisterStub(hostID, http.StatusCreated, InfraEnvID)
-		Expect(err).NotTo(HaveOccurred())
-		time.Sleep(6 * time.Second)
-
-		By("Validate register and get next step were called after command changed")
-		verifyNumberOfRegisterRequest("==", 2)
-		verifyNumberOfGetNextRequest(hostID, ">", 0)
-
-		Expect(deleteStub(registerStubID)).NotTo(HaveOccurred())
-		Expect(deleteStub(nextStepsStubID)).NotTo(HaveOccurred())
-	})
-
-	It("Next step exits - stop after next step and re-register", func() {
-		hostID := nextHostID()
-		registerStubID, err := addRegisterStub(hostID, http.StatusCreated, InfraEnvID)
-		Expect(err).NotTo(HaveOccurred())
-		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds, models.StepsPostStepActionExit)
-		Expect(err).NotTo(HaveOccurred())
-
-		Expect(startAgent()).NotTo(HaveOccurred())
-		time.Sleep(10 * time.Second)
-
-		By("Validate both register and next step called at least twice")
-		verifyNumberOfRegisterRequest(">", 1)
-		verifyNumberOfGetNextRequest(hostID, ">", 1)
-		Expect(deleteStub(registerStubID)).NotTo(HaveOccurred())
-		Expect(deleteStub(nextStepsStubID)).NotTo(HaveOccurred())
-	})
-
-	It("Next step exits - don't stop and keep polling for next step", func() {
-		hostID := nextHostID()
-		registerStubID, err := addRegisterStub(hostID, http.StatusCreated, InfraEnvID)
-		Expect(err).NotTo(HaveOccurred())
-		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds, models.StepsPostStepActionContinue)
-		Expect(err).NotTo(HaveOccurred())
-
-		Expect(startAgent()).NotTo(HaveOccurred())
-		time.Sleep(10 * time.Second)
-
-		By("Validate register request was called only once, next step multiple times")
-		verifyNumberOfRegisterRequest("==", 1)
-		verifyNumberOfGetNextRequest(hostID, ">", 1)
-		Expect(deleteStub(registerStubID)).NotTo(HaveOccurred())
-		Expect(deleteStub(nextStepsStubID)).NotTo(HaveOccurred())
-	})
-
-	Context("register action makes the agent to wait forever", func() {
-		var status int
-
-		It("register conflicted - cluster does not accept hosts", func() {
-			status = http.StatusConflict
-		})
-
-		It("register forbidden", func() {
-			status = http.StatusForbidden
-		})
-
-		AfterEach(func() {
-			hostID := nextHostID()
-			registerStubID, err := addRegisterStub(hostID, status, InfraEnvID)
-			Expect(err).NotTo(HaveOccurred())
-
-			nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds, "")
-			Expect(err).NotTo(HaveOccurred())
-
-			Expect(startAgent()).NotTo(HaveOccurred())
-			time.Sleep(10 * time.Second)
-
-			By("Validate only register request was called")
-			resp, err := http.Get(RequestsURL)
-			Expect(err).ShouldNot(HaveOccurred())
-			requests := &Requests{}
-			b, err := ioutil.ReadAll(resp.Body)
-			Expect(err).ShouldNot(HaveOccurred())
-			Expect(json.Unmarshal(b, &requests)).ShouldNot(HaveOccurred())
-			req := make([]*RequestOccurrence, 0, len(requests.Requests))
-			req = append(req, requests.Requests...)
-			Expect(len(req)).Should(Equal(1))
-			Expect(deleteStub(registerStubID)).NotTo(HaveOccurred())
-			Expect(deleteStub(nextStepsStubID)).NotTo(HaveOccurred())
-		})
-	})
-
-	It("register not found - agent should stop trying to register", func() {
-		hostID := nextHostID()
-		registerStubID, err := addRegisterStub(hostID, http.StatusNotFound, InfraEnvID)
-		Expect(err).NotTo(HaveOccurred())
-
-		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds, "")
-		Expect(err).NotTo(HaveOccurred())
-
-		Expect(startAgent()).NotTo(HaveOccurred())
-		time.Sleep(10 * time.Second)
-
-		By("Validate only register request was called")
+		// validate only register request was called
 		resp, err := http.Get(RequestsURL)
 		Expect(err).ShouldNot(HaveOccurred())
 		requests := &Requests{}
 		b, err := ioutil.ReadAll(resp.Body)
 		Expect(err).ShouldNot(HaveOccurred())
 		Expect(json.Unmarshal(b, &requests)).ShouldNot(HaveOccurred())
-		req := make([]*RequestOccurrence, 0, len(requests.Requests))
-		req = append(req, requests.Requests...)
+		req := make([]*RequestOccurence, 0, len(requests.Requests))
+		for _, r := range requests.Requests {
+			req = append(req, r)
+		}
+		Expect(len(req)).Should(Equal(1))
+		Expect(deleteStub(registerStubID)).NotTo(HaveOccurred())
+		Expect(deleteStub(nextStepsStubID)).NotTo(HaveOccurred())
+	})
+
+	It("register not found - agent should stop trying to register", func() {
+		hostID := nextHostID()
+		registerStubID, err := addRegisterStub(hostID, http.StatusNotFound)
+		Expect(err).NotTo(HaveOccurred())
+
+		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds)
+		Expect(err).NotTo(HaveOccurred())
+
+		Expect(startAgent()).NotTo(HaveOccurred())
+		time.Sleep(10 * time.Second)
+
+		// validate only register request was called
+		resp, err := http.Get(RequestsURL)
+		Expect(err).ShouldNot(HaveOccurred())
+		requests := &Requests{}
+		b, err := ioutil.ReadAll(resp.Body)
+		Expect(err).ShouldNot(HaveOccurred())
+		Expect(json.Unmarshal(b, &requests)).ShouldNot(HaveOccurred())
+		req := make([]*RequestOccurence, 0, len(requests.Requests))
+		for _, r := range requests.Requests {
+			req = append(req, r)
+		}
 		Expect(len(req)).Should(Equal(1))
 		Expect(deleteStub(registerStubID)).NotTo(HaveOccurred())
 		Expect(deleteStub(nextStepsStubID)).NotTo(HaveOccurred())
@@ -210,9 +106,9 @@ var _ = Describe("Agent tests", func() {
 
 	It("Verify nextInstructionSeconds", func() {
 		hostID := nextHostID()
-		registerStubID, err := addRegisterStub(hostID, http.StatusCreated, InfraEnvID)
+		registerStubID, err := addRegisterStub(hostID, http.StatusCreated)
 		Expect(err).NotTo(HaveOccurred())
-		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds, "")
+		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds)
 		Expect(err).NotTo(HaveOccurred())
 		Expect(startAgent()).NotTo(HaveOccurred())
 		time.Sleep(5 * time.Second)
@@ -224,9 +120,9 @@ var _ = Describe("Agent tests", func() {
 
 		By("verify changing nextInstructionSeconds to large number")
 		hostID = nextHostID()
-		registerStubID, err = addRegisterStub(hostID, http.StatusCreated, InfraEnvID)
+		registerStubID, err = addRegisterStub(hostID, http.StatusCreated)
 		Expect(err).NotTo(HaveOccurred())
-		nextStepsStubID, err = addNextStepStub(hostID, 100, "")
+		nextStepsStubID, err = addNextStepStub(hostID, 100)
 		Expect(err).NotTo(HaveOccurred())
 		Expect(startAgent()).NotTo(HaveOccurred())
 		time.Sleep(30 * time.Second)
@@ -240,7 +136,7 @@ var _ = Describe("Agent tests", func() {
 		hostID := nextHostID()
 		registerStubID, err := addNextStepClusterNotExistsStub(hostID)
 		Expect(err).NotTo(HaveOccurred())
-		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds, "")
+		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds)
 		Expect(err).NotTo(HaveOccurred())
 		Expect(startAgent()).NotTo(HaveOccurred())
 		time.Sleep(10 * time.Second)
@@ -252,13 +148,13 @@ var _ = Describe("Agent tests", func() {
 
 	It("Register recovery", func() {
 		hostID := nextHostID()
-		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds, "")
+		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds)
 		Expect(err).NotTo(HaveOccurred())
 		Expect(startAgent()).NotTo(HaveOccurred())
 		time.Sleep(1 * time.Second)
 		verifyRegisterRequest()
 		verifyGetNextRequest(hostID, false)
-		registerStubID, err := addRegisterStub(hostID, http.StatusCreated, InfraEnvID)
+		registerStubID, err := addRegisterStub(hostID, http.StatusCreated)
 		Expect(err).NotTo(HaveOccurred())
 		time.Sleep(time.Second * 6)
 		verifyRegisterRequest()
@@ -270,11 +166,11 @@ var _ = Describe("Agent tests", func() {
 
 	It("Step not exists", func() {
 		hostID := nextHostID()
-		registerStubID, err := addRegisterStub(hostID, http.StatusCreated, InfraEnvID)
+		registerStubID, err := addRegisterStub(hostID, http.StatusCreated)
 		Expect(err).NotTo(HaveOccurred())
 		stepID := "wrong-step"
 		stepType := models.StepType("Step-not-exists")
-		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds, "", &models.Step{StepType: stepType, StepID: stepID, Args: make([]string, 0)})
+		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds, &models.Step{StepType: stepType, StepID: stepID, Args: make([]string, 0)})
 		Expect(err).NotTo(HaveOccurred())
 		replyStubID, err := addStepReplyStub(hostID)
 		Expect(err).NotTo(HaveOccurred())
@@ -300,10 +196,10 @@ var _ = Describe("Agent tests", func() {
 
 	It("Execute echo", func() {
 		hostID := nextHostID()
-		registerStubID, err := addRegisterStub(hostID, http.StatusCreated, InfraEnvID)
+		registerStubID, err := addRegisterStub(hostID, http.StatusCreated)
 		Expect(err).NotTo(HaveOccurred())
 		stepID := "execute-step"
-		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds, "", &models.Step{
+		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds, &models.Step{
 			StepType: models.StepTypeExecute,
 			StepID:   stepID,
 			Command:  "echo",
@@ -336,9 +232,9 @@ var _ = Describe("Agent tests", func() {
 	})
 	It("Multiple steps", func() {
 		hostID := nextHostID()
-		registerStubID, err := addRegisterStub(hostID, http.StatusCreated, InfraEnvID)
+		registerStubID, err := addRegisterStub(hostID, http.StatusCreated)
 		Expect(err).NotTo(HaveOccurred())
-		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds, "",
+		nextStepsStubID, err := addNextStepStub(hostID, defaultnextInstructionSeconds,
 			&models.Step{
 				StepType: models.StepTypeExecute,
 				StepID:   "echo-step-1",
@@ -358,28 +254,20 @@ var _ = Describe("Agent tests", func() {
 					"world",
 				},
 			},
-			generateContainerStep(models.StepTypeInventory,
-				[]string{
-					"--net=host",
-					"-v", "/sys/block:/host/sys/block:ro", // discover disks by inventory
-					"-v", "/sys/class/net:/sys/class/net:ro", // discover network interfaces by inventory
-
-					// Asked by ghw - https://github.com/jaypipes/ghw/blob/master/pkg/linuxpath/path_linux.go
-					// Currently, we don't use all of ghw capabilities. But let's keep them for now as it's harmless.
+			&models.Step{
+				StepType: models.StepTypeInventory,
+				StepID:   "inventory-step",
+				Command:  "docker",
+				Args: []string{
+					"run", "--privileged", "--net=host", "--rm",
+					"-v", "/var/log:/var/log",
 					"-v", "/run/udev:/run/udev",
 					"-v", "/dev/disk:/dev/disk",
-					"-v", "/var/log:/host/var/log:ro",
-					"-v", "/proc/meminfo:/host/proc/meminfo:ro",
-					"-v", "/sys/kernel/mm/hugepages:/host/sys/kernel/mm/hugepages:ro",
-					"-v", "/proc/cpuinfo:/host/proc/cpuinfo:ro",
-					"-v", "/etc/mtab:/host/etc/mtab:ro",
-					"-v", "/sys/devices:/host/sys/devices:ro",
-					"-v", "/sys/bus:/host/sys/bus:ro",
-					"-v", "/sys/class:/host/sys/class:ro",
-					"-v", "/run/udev:/host/run/udev:ro",
-					"-v", "/dev/disk:/host/dev/disk:ro",
+					"-v", "/run/systemd/journal/socket:/run/systemd/journal/socket",
+					"quay.io/ocpmetal/assisted-installer-agent:latest",
+					"inventory",
 				},
-				[]string{"/usr/bin/inventory"}),
+			},
 		)
 		Expect(err).NotTo(HaveOccurred())
 		replyStubID, err := addStepReplyStub(hostID)
@@ -411,9 +299,7 @@ var _ = Describe("Agent tests", func() {
 		freeAddressesRequest := models.FreeAddressesRequest{}
 		for _, intf := range inventory.Interfaces {
 			for _, ipAddr := range intf.IPV4Addresses {
-				var ip net.IP
-				var cidr *net.IPNet
-				ip, cidr, err = net.ParseCIDR(ipAddr)
+				ip, cidr, err := net.ParseCIDR(ipAddr)
 				Expect(err).ToNot(HaveOccurred())
 				ones, _ := cidr.Mask.Size()
 				if ones < 24 {
@@ -425,23 +311,32 @@ var _ = Describe("Agent tests", func() {
 		}
 		if len(freeAddressesRequest) > 0 {
 			// TODO:: Need to support this part for all hosts.  Currently, we so a case that only virtual nics have ip addresses
-			var b []byte
-			b, err = json.Marshal(&freeAddressesRequest)
+			b, err := json.Marshal(&freeAddressesRequest)
 			Expect(err).ToNot(HaveOccurred())
 			err = deleteStub(nextStepsStubID)
 			Expect(err).NotTo(HaveOccurred())
-
-			step := generateContainerStep(models.StepTypeFreeNetworkAddresses,
-				[]string{"--net=host"},
-				[]string{"/usr/bin/free_addresses", string(b)})
-			_, err = addNextStepStub(hostID, defaultnextInstructionSeconds, "", step)
-			Expect(err).NotTo(HaveOccurred())
+			nextStepsStubID, err = addNextStepStub(hostID, defaultnextInstructionSeconds,
+				&models.Step{
+					StepType: models.StepTypeFreeNetworkAddresses,
+					StepID:   "free-addresses",
+					Command:  "docker",
+					Args: []string{"run", "--privileged", "--net=host", "--rm",
+						"-v", "/var/log:/var/log",
+						"-v", "/run/systemd/journal/socket:/run/systemd/journal/socket",
+						"quay.io/ocpmetal/assisted-installer-agent:latest",
+						"free_addresses",
+						string(b),
+					},
+				},
+			)
 			Eventually(func() bool {
 				return isReplyFound(hostID, &FreeAddressesVerifier{})
-			}, maxTimeout, 5*time.Second).Should(BeTrue())
+			}, 300*time.Second, 5*time.Second).Should(BeTrue())
 		}
 		err = deleteStub(registerStubID)
 		Expect(err).NotTo(HaveOccurred())
+		err = deleteStub(nextStepsStubID)
+		Expect(err).NotTo(HaveOccurred())
 		err = deleteStub(replyStubID)
 		Expect(err).NotTo(HaveOccurred())
 	})
@@ -476,7 +371,6 @@ func (i *InventoryVerifier) verify(actualReply *models.StepReply) bool {
 		inventory.CPU != nil && inventory.CPU.Count > 0 &&
 		len(inventory.Disks) > 0 &&
 		len(inventory.Interfaces) > 0 &&
-		inventory.Gpus != nil &&
 		inventory.Hostname != ""
 }
 
